@@ -97,15 +97,37 @@ class PlaylistsMixin(MixinProtocol):
                   "isAvailable": True,
                   "isExplicit": False,
                   "videoType": "MUSIC_VIDEO_TYPE_OMV",
+                  "inLibrary": False,
                   "feedbackTokens": {
                     "add": "AB9zfpJxtvrU...",
                     "remove": "AB9zfpKTyZ..."
-                }
+                  },
+                  "pinnedToListenAgain": False,
+                  "listenAgainFeedbackTokens": {
+                    "pin": "AB9zfpImL2k...",
+                    "unpin": "AB9zfpJt6pA..."
+                  },
+
               ]
             }
 
         The setVideoId is the unique id of this playlist item and
         needed for moving/removing playlist items
+
+        Collaborative playlists replace ``author`` with limited data about ``collaborators``::
+            {
+                "collaborators": {
+                    "text": "by Sample Author and 1 other",
+                    "avatars": [
+                        {
+                            "url": "https://yt3.ggpht.com/sample-author-photo"
+                        },
+                        {
+                            "url": "https://yt3.ggpht.com/sample-collaborator-photo"
+                        }
+                    ]
+                }
+            }
         """
         browseId = "VL" + playlistId if not playlistId.startswith("VL") else playlistId
         body = {"browseId": browseId}
@@ -146,6 +168,7 @@ class PlaylistsMixin(MixinProtocol):
         )
 
         playlist.update(parse_playlist_header_meta(header))
+        is_collaborative = "collaborators" in playlist
 
         playlist.update(parse_song_runs(nav(header, SUBTITLE_RUNS)[2 + playlist["owned"] * 2 :]))
 
@@ -184,9 +207,11 @@ class PlaylistsMixin(MixinProtocol):
         playlist["tracks"] = []
         content_data = nav(section_list, [*CONTENT, "musicPlaylistShelfRenderer"])
         if "contents" in content_data:
-            playlist["tracks"] = parse_playlist_items(content_data["contents"])
+            playlist["tracks"] = parse_playlist_items(
+                content_data["contents"], is_collaborative=is_collaborative
+            )
 
-            parse_func = lambda contents: parse_playlist_items(contents)
+            parse_func = lambda contents: parse_playlist_items(contents, is_collaborative=is_collaborative)
             playlist["tracks"].extend(
                 get_continuations_2025(content_data, limit, request_func_continuations, parse_func)
             )
@@ -201,6 +226,7 @@ class PlaylistsMixin(MixinProtocol):
         :param limit: How many items to return. Default: 100
         :return: List of playlistItem dictionaries. See :py:func:`get_playlist`
         """
+        self._check_auth()
         return self.get_playlist("LM", limit)
 
     def get_saved_episodes(self, limit: int = 100) -> JsonDict:
