@@ -3,6 +3,7 @@ from ytmusicapi.type_alias import JsonDict, JsonList
 from ..helpers import to_int
 from ._utils import *
 from .albums import parse_album_playlistid_if_exists
+from .artists import parse_artists_runs
 from .songs import *
 
 ALL_RESULT_TYPES = [
@@ -68,9 +69,10 @@ def parse_top_result(data: JsonDict, search_result_types: list[str]) -> JsonDict
     if result_type in ["playlist"]:
         search_result["playlistId"] = nav(data, MENU_PLAYLIST_ID)
         search_result["title"] = nav(data, TITLE_TEXT)
-        search_result["author"] = parse_song_artists_runs(nav(data, ["subtitle", "runs"])[2:])
+        search_result["author"] = parse_artists_runs(nav(data, ["subtitle", "runs"])[2:])
 
     if result_type in ["episode"]:
+        search_result["title"] = nav(data, TITLE_TEXT)
         search_result["videoId"] = nav(data, [*THUMBNAIL_OVERLAY_NAVIGATION, *WATCH_VIDEO_ID])
         search_result["videoType"] = nav(data, [*THUMBNAIL_OVERLAY_NAVIGATION, *NAVIGATION_VIDEO_TYPE])
         runs = nav(data, SUBTITLE_RUNS)[2:]
@@ -142,11 +144,7 @@ def parse_search_result(data: JsonDict, result_type: str | None, category: str |
 
     elif result_type == "song":
         search_result["album"] = None
-        if "menu" in data:
-            toggle_menu = find_object_by_key(nav(data, MENU_ITEMS), TOGGLE_MENU)
-            if toggle_menu:
-                search_result["inLibrary"] = parse_song_library_status(toggle_menu)
-                search_result["feedbackTokens"] = parse_song_menu_tokens(toggle_menu)
+        search_result.update(parse_song_menu_data(data))
 
     elif result_type == "upload":
         browse_id = nav(data, NAVIGATION_BROWSE_ID, True)
